@@ -3,7 +3,7 @@ This script allows to capture Ned's video streaming and to make some image proce
 """
 
 # Imports
-from pyniryo.api import *
+from pyniryo2 import *
 import pyniryo.vision as vision
 
 simulation_mode = True
@@ -14,20 +14,25 @@ robot_ip_address = robot_ip_address_simulation if simulation_mode else robot_ip_
 
 # Set Observation Pose. It's where the robot will be placed for streaming
 observation_pose = PoseObject(
-    x=0.2, y=0.0, z=0.34,
-    roll=0, pitch=1.57, yaw=-0.2,
+    x=0.17, y=0.0, z=0.35,
+    roll=0, pitch=1.57, yaw=0.0,
 )
 
 
 def video_stream(niyro_robot):
+    """
+
+    :type niyro_robot: NiryoRobot
+    :rtype: None
+    """
     # Getting calibration param
-    mtx, dist = niyro_robot.get_camera_intrinsics()
+    mtx, dist = niyro_robot.vision.get_camera_intrinsics()
     # Moving to observation pose
-    niyro_robot.move_pose(*observation_pose.to_list())
+    niyro_robot.arm.move_pose(observation_pose)
 
     while "User do not press Escape neither Q":
         # Getting image
-        img_compressed = niyro_robot.get_img_compressed()
+        img_compressed = niyro_robot.vision.get_img_compressed()
         # Uncompressing image
         img_raw = vision.uncompress_image(img_compressed)
         # Undistorting
@@ -54,16 +59,16 @@ def video_stream(niyro_robot):
         if key in [27, ord("q")]:  # Will break loop if the user press Escape or Q
             break
 
-    niyro_robot.set_learning_mode(True)
+    niyro_robot.arm.set_learning_mode(True)
 
 
 if __name__ == '__main__':
     # Connect to robot
     robot = NiryoRobot(robot_ip_address)
     # Calibrate robot if robot needs calibration
-    robot.calibrate_auto()
+    robot.arm.calibrate_auto()
     # Launching main process
     video_stream(robot)
     # Releasing connection
-    robot.close_connection()
+    robot.end()
 
